@@ -26,7 +26,7 @@ var group___math =
       [ "operator Degree", "group___math.html#ga166c0b2a2264eac93345461f93005b6e", null ]
     ] ],
     [ "Ogre::AxisAlignedBox", "class_ogre_1_1_axis_aligned_box.html", [
-      [ "Corners", "class_ogre_1_1_axis_aligned_box.html#ac546dc901a1f32d30b9287928c6c7c99", null ],
+      [ "Corners", "class_ogre_1_1_axis_aligned_box.html#a769c7e06e985a9f6d47cd5be57cef4d7", null ],
       [ "Extent", "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443e", [
         [ "EXTENT_NULL", "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443ea5046ce9384ab8647fb3c58e03d5446c9", null ],
         [ "EXTENT_FINITE", "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443eafa5a4b01ba1d49c7b3db966223bf6642", null ],
@@ -110,12 +110,12 @@ var group___math =
       [ "intWrite", "class_ogre_1_1_bitwise.html#afa88e9d32bbc468ac3ee803ee4228ca1", null ],
       [ "intRead", "class_ogre_1_1_bitwise.html#ad0fcaa2e4f445d1e9c1fb69291061dec", null ],
       [ "floatToHalf", "class_ogre_1_1_bitwise.html#aa02a9c5a117baf2da38ad562c2130681", null ],
-      [ "floatToHalfI", "class_ogre_1_1_bitwise.html#ad98268f6e1288301c0471e345e98cd1e", null ],
+      [ "floatToHalfI", "class_ogre_1_1_bitwise.html#ae135638c0cf50cd81dc6355325e0ed21", null ],
       [ "halfToFloat", "class_ogre_1_1_bitwise.html#abb3cbaa74865420859ba7b1061f8d3f3", null ],
-      [ "halfToFloatI", "class_ogre_1_1_bitwise.html#a7ccd62b11c082f76d4972e27896c6028", null ]
+      [ "halfToFloatI", "class_ogre_1_1_bitwise.html#ae009f79c8946b451ca7ea2ec599eaf3b", null ]
     ] ],
     [ "Ogre::ConvexBody", "class_ogre_1_1_convex_body.html", [
-      [ "PolygonList", "class_ogre_1_1_convex_body.html#a4a13eb065fe856b0354d523394e9dfaa", null ],
+      [ "PolygonList", "class_ogre_1_1_convex_body.html#a1c5095efca4da37552dcbe1de92e62a4", null ],
       [ "ConvexBody", "class_ogre_1_1_convex_body.html#a55e376da89733093d9061f2b5acebfb2", null ],
       [ "~ConvexBody", "class_ogre_1_1_convex_body.html#a6f643f10031458c33cc9b51dc4a8f893", null ],
       [ "ConvexBody", "class_ogre_1_1_convex_body.html#ae9792f9784f57a75d89a8aecb9ee2f58", null ],
@@ -205,30 +205,30 @@ var group___math =
     ] ],
     [ "Ogre::EdgeData", "class_ogre_1_1_edge_data.html", [
       [ "Edge", "struct_ogre_1_1_edge_data_1_1_edge.html", [
-        [ "triIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#ac5a9a9bc9dfc4d301058ee4e5c407f8f", null ],
-        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#aad95e9ee5714e7413367fe6c8ba5dd20", null ],
-        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#a01c602e99ec1f7296cca73595e0ab55e", null ],
+        [ "triIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#a6ba1f2209d1e9014c76c6acc8f626b96", null ],
+        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#aa04881db8275f906b6209b67f77463ab", null ],
+        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#af8e9e2d2507bd8781c1b34020b4e774a", null ],
         [ "degenerate", "struct_ogre_1_1_edge_data_1_1_edge.html#a83b46b6487ee08a92449c8698fc8fc11", null ]
       ] ],
       [ "EdgeGroup", "struct_ogre_1_1_edge_data_1_1_edge_group.html", [
-        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a86c3d3704b9370b9601be1b1ef21316f", null ],
+        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a438a681003c85af04799a2f31988e7e9", null ],
         [ "vertexData", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a1564edb1edb8ee140fd14ee683cae134", null ],
-        [ "triStart", "struct_ogre_1_1_edge_data_1_1_edge_group.html#ac1492097f952ad47429aed81471d1308", null ],
-        [ "triCount", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a41b7c17951a90ca2a2518b497749fccf", null ],
+        [ "triStart", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a30fb6c301c0f8cb5ffb940a31a6d6941", null ],
+        [ "triCount", "struct_ogre_1_1_edge_data_1_1_edge_group.html#af2d92af1d37412b1d16347129411659b", null ],
         [ "edges", "struct_ogre_1_1_edge_data_1_1_edge_group.html#ac1cefca66bbcb95e3a5b8967bbcd94f2", null ]
       ] ],
       [ "Triangle", "struct_ogre_1_1_edge_data_1_1_triangle.html", [
         [ "Triangle", "struct_ogre_1_1_edge_data_1_1_triangle.html#ac676a82255cafa821af2f4143160f2b1", null ],
-        [ "indexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#a77b9a1e73bea6c8cdbe3197a1311ad38", null ],
-        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#a8bf63fc09c7508d4c4863168442520db", null ],
-        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#af3610ee6a688cccc061392263bde1929", null ],
-        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#a7d4ef75a8c204871c1829dbae25e5f7d", null ]
+        [ "indexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#a9d88cf8afcd62b9ee2c85cd7d1a4b47b", null ],
+        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#ac923c944013258cd8935c0e3650f2cc3", null ],
+        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#a56a6f686b4e40b69da5a356445cbf258", null ],
+        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#a4aee7f563ba413db670ec0713476400d", null ]
       ] ],
-      [ "TriangleFaceNormalList", "class_ogre_1_1_edge_data.html#a64e153ea58ec4f80064986f2d9db201d", null ],
-      [ "TriangleLightFacingList", "class_ogre_1_1_edge_data.html#a40386af98df21e634c60b85d4434684b", null ],
-      [ "TriangleList", "class_ogre_1_1_edge_data.html#afaf35a82abd84227e184cf35be1255b6", null ],
-      [ "EdgeList", "class_ogre_1_1_edge_data.html#aa25f4ff55b3a62137c8d74b417a2e127", null ],
-      [ "EdgeGroupList", "class_ogre_1_1_edge_data.html#aead5d3649daa5415ad9418859ba1b20d", null ],
+      [ "TriangleFaceNormalList", "class_ogre_1_1_edge_data.html#a0c3b6027adaefeded70c73c18fc5431c", null ],
+      [ "TriangleLightFacingList", "class_ogre_1_1_edge_data.html#ac1a64463d85aedbfb38a22cc4bf37390", null ],
+      [ "TriangleList", "class_ogre_1_1_edge_data.html#a93de48885b7354fd8eef4501ab9837b8", null ],
+      [ "EdgeList", "class_ogre_1_1_edge_data.html#a4051e73185e97a35d022e0cbea91d326", null ],
+      [ "EdgeGroupList", "class_ogre_1_1_edge_data.html#a31d0c51b310b6898b168f9c98d94aa24", null ],
       [ "EdgeData", "class_ogre_1_1_edge_data.html#aca13bc3f48d35cacaac6fb72834ab649", null ],
       [ "updateTriangleLightFacing", "class_ogre_1_1_edge_data.html#abc392e96ecd65467b7e17e56f5b6751d", null ],
       [ "updateFaceNormals", "class_ogre_1_1_edge_data.html#a06f4e92565a4b5334aafc92dd923bd12", null ],
@@ -245,7 +245,8 @@ var group___math =
       [ "addVertexData", "class_ogre_1_1_edge_list_builder.html#a9845e2f91660819164a627c661f5d107", null ],
       [ "addIndexData", "class_ogre_1_1_edge_list_builder.html#ae4af3550dfe4948680078a087377bfbf", null ],
       [ "build", "class_ogre_1_1_edge_list_builder.html#aa76568f1c0c49f3f9ff16dfb304f1571", null ],
-      [ "log", "class_ogre_1_1_edge_list_builder.html#a66aa1d48de5385be8233c8733af99186", null ]
+      [ "log", "class_ogre_1_1_edge_list_builder.html#a66aa1d48de5385be8233c8733af99186", null ],
+      [ "geometryLess", "class_ogre_1_1_edge_list_builder.html#a99d7b191452d6c4848576f0f3703e0a6", null ]
     ] ],
     [ "Ogre::Math", "class_ogre_1_1_math.html", [
       [ "RandomValueProvider", "class_ogre_1_1_math_1_1_random_value_provider.html", [
@@ -456,7 +457,7 @@ var group___math =
       [ "d", "class_ogre_1_1_plane.html#a8e7de1712320968bee111002bc2938b8", null ]
     ] ],
     [ "Ogre::PlaneBoundedVolume", "class_ogre_1_1_plane_bounded_volume.html", [
-      [ "PlaneList", "class_ogre_1_1_plane_bounded_volume.html#adffb808d81baf5b8342fc8959e8123bf", null ],
+      [ "PlaneList", "class_ogre_1_1_plane_bounded_volume.html#a52f7c389144c1c587d7fea9e2b8d2a12", null ],
       [ "PlaneBoundedVolume", "class_ogre_1_1_plane_bounded_volume.html#a9f3907950c9fd279e01ac1d4a03d9871", null ],
       [ "PlaneBoundedVolume", "class_ogre_1_1_plane_bounded_volume.html#a1f07490e0ddb2809e1e2b71a89c23856", null ],
       [ "intersects", "class_ogre_1_1_plane_bounded_volume.html#ac92a3d627da4cadbc9ebe7331b368e6e", null ],
@@ -466,9 +467,9 @@ var group___math =
       [ "outside", "class_ogre_1_1_plane_bounded_volume.html#a4d323aac2569fdb268dd6dda2801896e", null ]
     ] ],
     [ "Ogre::Polygon", "class_ogre_1_1_polygon.html", [
-      [ "VertexList", "class_ogre_1_1_polygon.html#a72d1c26d937a8a3f8caad158c7d71745", null ],
-      [ "EdgeMap", "class_ogre_1_1_polygon.html#a75ad4cca62e4f65b7f6007ee29c42644", null ],
-      [ "Edge", "class_ogre_1_1_polygon.html#ae6e7019c9a29ef5eb95e6c063d355830", null ],
+      [ "VertexList", "class_ogre_1_1_polygon.html#a9c4c9bf9ae3a6ec59115496a1490e71e", null ],
+      [ "EdgeMap", "class_ogre_1_1_polygon.html#a2fa27f282f9404b1b00acf7e37b45b4a", null ],
+      [ "Edge", "class_ogre_1_1_polygon.html#a40c084fee97b6c80511ceddcd80a2ca5", null ],
       [ "Polygon", "class_ogre_1_1_polygon.html#a1530c1d4761371c423916f4b497d612e", null ],
       [ "~Polygon", "class_ogre_1_1_polygon.html#a7ce008c85c18f7c28776a7e6b5fb60f3", null ],
       [ "Polygon", "class_ogre_1_1_polygon.html#a86fb38e409c2792034bb6754ff373dc0", null ],
@@ -649,9 +650,9 @@ var group___math =
         [ "vertexSplits", "struct_ogre_1_1_tangent_space_calc_1_1_result.html#adc7a5f1543644476242dfad6552342b6", null ],
         [ "indexesRemapped", "struct_ogre_1_1_tangent_space_calc_1_1_result.html#a0e5e34d6936c7a3e76ad6e4d03688df8", null ]
       ] ],
-      [ "VertexSplit", "class_ogre_1_1_tangent_space_calc.html#af7248e9a56104604d70decacbddc24b6", null ],
-      [ "IndexRemapList", "class_ogre_1_1_tangent_space_calc.html#af7aa66e32c70fac39f0c518393015321", null ],
-      [ "VertexSplits", "class_ogre_1_1_tangent_space_calc.html#aba0d535d599204aa3b58fe0717b8bbb5", null ],
+      [ "VertexSplit", "class_ogre_1_1_tangent_space_calc.html#a3b4ae87819072eef7073c3e71a0735be", null ],
+      [ "IndexRemapList", "class_ogre_1_1_tangent_space_calc.html#af6497ad40b68863ff56ad526dd8cea2a", null ],
+      [ "VertexSplits", "class_ogre_1_1_tangent_space_calc.html#abe9e4513618517d0b4c98da866b85648", null ],
       [ "TangentSpaceCalc", "class_ogre_1_1_tangent_space_calc.html#a33eeb35f74cfa2d2c90ab7b138763752", null ],
       [ "clear", "class_ogre_1_1_tangent_space_calc.html#afd150caf2af93ec05fcbc836641e894a", null ],
       [ "setVertexData", "class_ogre_1_1_tangent_space_calc.html#aac1530e73ac67068755e65063965fe98", null ],
